@@ -838,7 +838,7 @@ public class Imager {
 	// Old way
 	//String[] elements = surveyID.split(" ");
 
-	Pattern p = Pattern.compile("(i|pi|pa|q|u)$");  
+	Pattern p = Pattern.compile("(i|pi|pa|q|u|pi/i)$", Pattern.CASE_INSENSITIVE);  
 	String[] elements = p.split(surveyID);  
 	String base=elements[0];  
 	// The base is anything up-to and including the numbers.  
