@@ -153,7 +153,7 @@ public class Hpx extends Projecter {
     public Hpx() {
 	this(9);
     }
-    
+        
     /** Interleaver to do calculations */
     private Interleave weaver;
     
@@ -221,15 +221,20 @@ public class Hpx extends Projecter {
      * @return 
      */
     public boolean validPosition(double[] plane) {
+        if (!super.validPosition(plane)) {
+            return false;
+        }
+        double[] norm = normCoords(plane);
         // Get the tile indices.
-        int x = (int) Math.floor(plane[0]*invLength);
-        int y = (int) Math.floor(plane[1]*invLength);
+        int x = (int) Math.floor(norm[0]);
+        int y = (int) Math.floor(norm[1]);
         
         // Get the index of the tile rembering that the first tile
         // starts at [-2,-3]
-        int tile = (4*(y+3) + (x+2));       
-	return super.validPosition(plane) &&
-          // It's within our 4x6 tile
+        int tile = (4*(y+3) + (x+2));
+        
+	return 
+          // It's within our 4x6 tiling
           x >= -2 && x < 2 && 
           y >= -3 && y < 3 &&
           // ... and it's not a blank tile
