@@ -27,18 +27,18 @@ public class NN extends skyview.geometry.Sampler {
 	trans.transform(in, out);
 	
 //	System.out.println("NNSampler("+testCounter+") "+in[0]+","+in[1]+"   -->  "+out[0]+","+out[1]);
-	testCounter += 1;
+//	testCounter += 1;
 	
 	// Remember that the pixel value is assumed
 	// to be at the center of the pixel not the corner.
-	int x = (int) out[0];
-	int y = (int) out[1];
+	long x = (long) out[0];
+	long y = (long) out[1];
 	
 	if (x < 0 || x >= inWidth || y < 0 || y >= inHeight) {
 //	    System.err.println("NNSampler: No data");
 	    return;
 	} else {
-	    for (int k=0; k < inDepth; k += 1) {
+	    for (long k=0; k < inDepth; k += 1) {
 		double val = inImage.getData(x+inWidth*y+k*inWidth*inHeight);
 		outImage.setData(pix+k*outWidth*outHeight, val);
 //	        System.out.println("NNSampler("+k+")=  "+val);
