@@ -14,6 +14,8 @@
 
 package skyview.geometry.sampler;
 
+
+import skyview.executive.Settings;
 import skyview.survey.Image;
 
 public class Spline extends skyview.geometry.Sampler {
@@ -70,6 +72,7 @@ public class Spline extends skyview.geometry.Sampler {
                 int[] bnds = {0, ow-1, oh*ow - ow, oh*ow-1};
                 getBoundedInput(inImage, bnds);
             } else {
+                
                 this.image  = new double[inImage.getWidth()*inImage.getHeight()];
 	        for (int i=0; i<image.length; i += 1) {
 	            image[i] = inImage.getData(i);
@@ -156,6 +159,86 @@ public class Spline extends skyview.geometry.Sampler {
 	    }
 	}
     }
+    
+    
+    // Look for a replacement value that is
+    // either 10% above or below the range.
+    double getReplaceValue(boolean less, double[] vals) {
+        boolean ok = false;
+        double mn= 1.e30;
+        double mx= -mn; 
+        int nanCount = 0;
+        for (double val: vals) {
+            if (val == val) {
+                ok = true;
+                if (val < mn) mn = val;
+                if (val > mx) mx = val;
+            } else {
+                nanCount += 1;
+            }
+        }
+        // If we have no non-NaN values, or we have all NaN values then
+        // we don't need to do anything special to handle them.  Return this
+        // special value to make that clear.
+        if (!ok || nanCount == 0) {
+            return Double.NaN;
+        }
+        double delta = 0.1*(mx-mn);
+        System.err.println("GetReplaceValue debug:"+ok+" "+mn+" "+mx+" "+delta+" "+nanCount);
+        if (less) {
+            return mn-delta;
+        } else {
+            return mx+delta;
+        }
+    }
+
+    /** Handle NaNs in the input image.  Behavior is controlled by the
+     *  SplineNaNs setting:
+     *     "skip"   -> don't do anything.  In this case the NaNs may corrupt
+     *                 the coefficient computation.
+     *     "min"    -> replace NaNs with a value 10% below the range of non-NaN values.
+     *                 This is the default.
+     *     "max"    -> replace NaNs with a value 10% above the range of non-NaN values.
+     *      value   -> replace NaNs with the specified value.
+     * 
+     *   Note that if the image has no NaNs or if the image is all NaNs then nothing
+     *   is done.
+     * 
+     * @param image   The array in which NaNs are to be replaced.
+     */    
+    void handleNaNs(double[] image) {
+        // fixNaNs can have the values:
+        //    min -- replace NaNs by 10% below min
+        //    max -- replace NaNs by 10% above max
+        //    skip -- don't replace NaNs
+        //    value -- number to replace NaNs with.
+        String fixNaNs = Settings.get("SplineNaNs", "min");
+        if (fixNaNs.equals("1")  || fixNaNs.length() == 0) {
+            fixNaNs = "min";
+        }
+        fixNaNs = fixNaNs.toLowerCase();
+        if (fixNaNs.equals("skip")) {
+            return;
+        }
+        double replace = 0;
+        if (fixNaNs.equals("min")  || fixNaNs.equals("max")) {
+            replace = getReplaceValue(fixNaNs.equals("min"), image);
+            if (! (replace == replace)) {
+                return;  // Don't need to (or can't) do anything
+            }
+        } else {
+            try {
+                replace = Double.parseDouble(fixNaNs);
+            } catch (Exception e) {
+                throw new IllegalArgumentException("Invalid SplineNaNs value: "+fixNaNs);
+            }
+        }
+        for (int i=0; i<image.length; i += 1) {
+            if (image[i] != image[i]) {
+                image[i] = replace;
+            }
+        }
+    }
 	 
        
      /** Transform the image to spline coefficients on the image copy.
@@ -165,6 +248,8 @@ public class Spline extends skyview.geometry.Sampler {
       * violated Java conventions.
       */
      private  int samplesToCoefficients () {
+         
+        handleNaNs(image);
     
     	double[]  Line;
     	double[]  Pole = new double[2];
