@@ -1,6 +1,8 @@
 package skyview.process;
 
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import skyview.survey.Image;
 import skyview.geometry.Sampler;
@@ -10,14 +12,35 @@ import skyview.geometry.TransformationException;
 
 import nom.tam.fits.Header;
 import skyview.executive.Settings;
+import skyview.survey.FitsImage;
 
 /** A mosaicker is an object which creates
  *  a new image from a set of input images.
  */
-public class Mosaicker implements Processor {
+public class Mosaicker extends Processor {
  
+    /** An instance of this structure indicates that the given parameter
+     *  had the given value for the given number of pixels.
+     */
+    private class TrackedDatum {
+        String name;
+        double value;
+        int count;
+        TrackedDatum(String name, double value, int count) {
+            this.name = name; this.value=value; this.count = count;
+        }
+    }
+    
+    private List<TrackedDatum> tracking;
+    private String[] trackedKeywords;
+    
     private Map<String, Integer> usedImages = new HashMap<String,Integer>();
     
+    public boolean updatesOutput() {
+        return true;
+    }
+    
+    
     /** Get the name of this component */
     public String getName() {
 	return "Mosaicker";
@@ -137,12 +160,36 @@ public class Mosaicker implements Processor {
 	    }
             if (currCount > 0) {
                 addPixels(input[currImg].getName(), currCount);
+                if (Settings.has("trackedInputs")) {
+                    track(input[currImg], currCount);
+                }
                 currCount = 0;
             }
 	}
         setUsedImages();
     }
     
+    private void track(Image curr, int count) {
+        
+        if (tracking == null) {
+            // Initialize tracking.
+            tracking = new ArrayList<TrackedDatum>();
+            trackedKeywords = Settings.getArray("trackedInputs");
+        }
+        if (!(curr instanceof FitsImage)) {
+            return;
+        }
+        Header hdr = ((FitsImage)curr).getHeader();
+        for (String key: trackedKeywords) {
+            double val = hdr.getDoubleValue(key, Double.NaN);
+            if (val == val) {
+                tracking.add(new TrackedDatum(key, val, count));                
+            }
+        }
+    }
+    
+    
+    
     protected void addPixels(String name, int count) {
         Integer oldPix = usedImages.get(name);
         if (oldPix == null) {
@@ -156,7 +203,7 @@ public class Mosaicker implements Processor {
         String used = "";
         String sep  = "";
         for (String name: usedImages.keySet()) {
-            used += sep + name+":"+usedImages.get(name);
+            used += sep + name+"|"+usedImages.get(name);
             sep   = ",";
         }
         Settings.add("_usedImages", used);
@@ -222,7 +269,7 @@ public class Mosaicker implements Processor {
 	    } else {
                 String[] imgs = usedImages.split(",");
                 for (String img: imgs) {
-                    String[] flds = img.split(":");                
+                    String[] flds = img.split("\\|");                
 	            h.insertHistory("  Used image:"+flds[0]);
                     h.insertHistory("       Pixels:"+flds[1]);
                 }
@@ -232,6 +279,49 @@ public class Mosaicker implements Processor {
 	    System.err.println("Error updating FITS header:\n   "+e);
 	    // Just continue
 	}
+        
+        if (Settings.has("trackedInputs")) {
+            setTracked(h);
+        }
+    }
+    
+    void setTracked(Header h) {
+        try {
+            String[] keys = Settings.getArray("trackedInputs");
+            h.insertComment("");
+            h.insertComment("  Tracked Inputs:");
+            h.insertComment("  Following keywords copied or averaged from inputs");
+            h.insertComment("");
+            for (String key: keys) {
+                boolean found = false;
+                double vmin =  1.e100;
+                double vmax = -1.e100;
+                double sum  = 0;
+                long   totalCnt = 0;
+                for (TrackedDatum t: tracking) {
+                    if (t.name.equals(key)) {
+                        totalCnt += t.count;
+                        double v = t.value;
+                        if (v > vmax) {
+                            vmax = v;
+                        }
+                        if (v < vmin) {
+                            vmin = v;
+                        }
+                        sum += v*t.count;
+                    }
+                }
+                String comm = " Copied from input";
+                if (vmin != vmax) {
+                    comm = String.format("  Range [ %12.6g - %12.6g ]", vmin, vmax);
+                }
+                h.addValue(key, sum/totalCnt, comm);
+            }
+            h.insertComment("");
+            
+        } catch (nom.tam.fits.FitsException e) {
+            System.err.println("Error update FITS header for tracked inputs: "+e);
+        }        
     }
     
     /** Find appropriate ordinal suffix for
