@@ -290,17 +290,6 @@ public class CGIInitiator {
                  + "selected=skyview'>contact us</a> if you have questions "
                  + "about this error.\n We welcome your questions and feedback."
                  + " <p>");
-         System.out.println("<br><input type=button"
-                 + " onclick='document.getElementById(\"traceback\")."
-                 + "style.visibility=\"visible\"' value='Show Traceback'>");
-         System.out.println("<div id=traceback style='visibility:hidden'>"
-                 + "<pre>");
-         System.out.println("Java Stacktrace:\n");
-         StringWriter sw = new StringWriter();
-         PrintWriter pw = new PrintWriter(sw);
-         e.printStackTrace(pw);
-         String stacktrace = sw.getBuffer().toString();
-         System.out.println(StringEscapeUtils.escapeHtml4(stacktrace).replace("'", "&#39;"));
          System.out.println("</pre></div></body></html>");
       } finally {
          System.exit(0);
