@@ -30,7 +30,7 @@ public class HealPixImageFactory implements ImageFactory {
 	    return new HealPixImage(file);
 	} catch (Exception e) {
 	    e.printStackTrace();
-	    throw new Error("Irrecoverable error for HealPix file: "+file);
+	    throw new Error("Irrecoverable error for HealPix file: "+file, e);
 	}
     }
 }
