@@ -25,11 +25,9 @@ import java.io.BufferedReader;
 import java.io.InputStreamReader;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.zip.GZIPInputStream;
-import nom.tam.fits.FitsException;
 import nom.tam.fits.HeaderCard;
 import skyview.request.TextReplacer;
 
@@ -561,6 +559,7 @@ public class XMLSurvey implements Survey {
 	if (images.size() == 0) {
 	    return new Image[0];
 	} else {
+	    Image[] list       = new Image[images.size()];
 	    
 	    // Create the image factory
 	    ImageFactory imFac = (ImageFactory) 
@@ -568,34 +567,11 @@ public class XMLSurvey implements Survey {
 	    if (imFac == null) {
 		throw new Error("Unable to create image factory");
 	    }
-            List<Image> imageList = new ArrayList<Image>();
-            System.err.println("Loading images:"+images.size());
 	    for (int i=0; i<images.size(); i += 1) {
 		String s = images.get(i);
-                try {
-                    System.err.println("At image:"+i+" "+s);
-		    Image img  = imFac.factory(s);
-                    imageList.add(img);
-                    System.err.println("Image created:"+img);
-                } catch (Error e) {
-                    System.err.println("Here");
-                    System.err.println("keys:");
-                    for (String key: Settings.getKeys()) {
-                        System.err.print(" "+key);                        
-                    }
-                    System.err.println();
-                    System.err.println("Settings:"+Settings.has("AllowFitsErrors"));
-                    if (Settings.has("AllowFitsErrors")) {
-                        System.err.println("Continuing");
-                        continue;  
-                    } else {
-                        System.err.println("Rethrowing");
-                        throw e;  // Just rethrow error.
-                    }
-                }
-                System.err.println("Finished index:"+i);
+		list[i]  = imFac.factory(s);
 	    }
-	    return imageList.toArray(new Image[0]);
+	    return list;
 	}
     }
     
