@@ -25,6 +25,8 @@ import java.io.Reader;
 import java.util.HashMap;
 import java.util.ArrayList;
 
+import org.apache.commons.lang3.StringEscapeUtils;
+
 import net.ivoa.util.CGI;
 
 /** This class writes an HTML description of a survey based upon
@@ -221,7 +223,8 @@ public class XMLSurveyDescription {
     }
     
     static void printRegimeContents(String regime, HashMap<String, String> surveys) throws Exception {
-	System.out.println("<p><b> " + regime+" surveys </b><br>");
+        String escapedRegime = StringEscapeUtils.escapeHtml4(regime).replace("'", "&#39;");
+        System.out.println("<p><b> " + escapedRegime + " surveys </b><br>");
 	regime = regime.toLowerCase();
 	ArrayList<String> files = new ArrayList<String>();
 	ArrayList<String> names = new ArrayList<String>();
@@ -239,7 +242,8 @@ public class XMLSurveyDescription {
 	// Sort them
 	java.util.Collections.sort(names);
 	for (String name: names) {
-	    System.out.print("<a href='#"+name+"'>"+name+"</a><br>");
+            String escapedName = StringEscapeUtils.escapeHtml4(name).replace("'", "&#39;");
+	    System.out.println("<a href='#" + escapedName + "'>" + escapedName + "</a><br>");
 	}
 
     }
