@@ -1,6 +1,7 @@
 package skyview.test;
 
 import java.awt.image.BufferedImage;
+import java.util.Arrays;
 import skyview.executive.Imager;
 import skyview.executive.Settings;
 
@@ -32,9 +33,11 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.regex.Pattern; 
 import javax.imageio.ImageIO;
 import nom.tam.fits.Fits;
 import nom.tam.util.ArrayFuncs;
+import org.apache.commons.lang3.StringUtils;
 
 /**
  * This class does basic testing of the features of the SkyView JAR. It
@@ -99,6 +102,10 @@ public class NewTester {
     /** min/maxTest may be overridden by the logical variables MIN_TEST and MAX_TEST */
     private static String minTest = "0";
     private static String maxTest = "999999";
+    private static String skip_test = "";
+    private static String skip_tests[];  
+    private static String only_test = "";
+    private static String only_tests[];  
     
     /** The designator for the test.  New tests should be added at the end of existing tests
      *  or within a test but immediately befor an 'base.up()'. 
@@ -154,8 +161,14 @@ public class NewTester {
         if (System.getenv("MAX_TEST") != null) {
             maxTest = System.getenv("MAX_TEST");
         }
-        
-        
+        if (System.getenv("SKIP_TESTS") != null) {
+            skip_test=System.getenv("SKIP_TESTS");
+            skip_tests=skip_test.split(",");
+        }
+        if (System.getenv("ONLY_TESTS") != null) {
+            only_test=System.getenv("ONLY_TESTS");
+            only_tests=only_test.split(",");
+        }        
         // Starting with 3.2.0 that we point to the correct test files.
         String vers = Settings.get("version");
         String xmlurlprefix = Settings.get("XMLURLPrefix");
@@ -213,7 +226,7 @@ public class NewTester {
             "shassa_c", "shassa_cc", "shassa_h", "shassa_sm",
             "4850mhz", "iris12", "iris25", "iris60", "iris100",
             "wfcf1", "wfcf2", "euve83", "euve171", "euve405", "euve555",
-            "neat", "rass-int broad", "rass-int hard", "rass-int soft",
+            "rass-int broad", "rass-int hard", "rass-int soft",
             "wisew1", "wisew2", "wisew3", "wisew4",
             "EBHIS",
             "TGSS ADR1", 
@@ -259,7 +272,7 @@ public class NewTester {
             "mell-r", "mell-g", "mell-b"
         };
         
-        String[] hips = {"SwiftXRTCnt", "SwiftXRTInt", "SwiftXRTEXP"};
+        String[] hips = {"SwiftXRTCnt", "SwiftXRTInt", "SwiftXRTEXP", "tess"};
         
         String[] goodsSurveys = new String[] {
             "GOODSNVLA", "GOODSMIPS", "GOODSACISFB", "GOODSACISSB","GOODSACISHB",
@@ -419,7 +432,13 @@ public class NewTester {
             for (String survey: hips) {
                 currentSettings.remove("Size");
                 currentSettings.put("scale", ""+scale );
-                currentSettings.put("Position", "0,0");
+                //Tess coverage is different
+                if ( Pattern.compile(Pattern.quote("tess"), Pattern.CASE_INSENSITIVE).matcher(survey).find() ) {
+                    currentSettings.put("Position", "0,90");
+                }
+                else {
+                    currentSettings.put("Position", "0,0");
+                }
                 currentSettings.put("Survey", survey);
                 test(true);
             }
@@ -747,6 +766,14 @@ public class NewTester {
      * Should the current test be run?
      */
     private static boolean included(HCounter base) {
+        if (only_tests != null && only_tests.length > 0) {
+            return !base.before(minTest) && !base.after(maxTest) && 
+                    Arrays.asList(only_tests).contains(base.toString());
+        }
+        if (skip_tests != null && skip_tests.length > 0) {
+            return !base.before(minTest) && !base.after(maxTest) && 
+                    !Arrays.asList(skip_tests).contains(base.toString());
+        }
         return !base.before(minTest) && !base.after(maxTest);
     }
 
