@@ -9,7 +9,7 @@ import skyview.geometry.DepthSampler;
 
 import skyview.executive.Settings;
 
-public class CatalogProcessor implements skyview.process.Processor {
+public class CatalogProcessor extends skyview.process.Processor {
     
     private static HashMap <String,ConeQuerier> requests = new HashMap<String,ConeQuerier>();
     private ArrayList<Thread> threads = new ArrayList<Thread>();
@@ -38,6 +38,10 @@ public class CatalogProcessor implements skyview.process.Processor {
 	lastProcessor = this;
     }
     
+    public boolean updatesOutput() {
+        return false;
+    }
+    
     public String getName() {
 	return "CatalogProcessor";
     }
